@@ -3,7 +3,7 @@ from qds_ops.entities.web import Web
 class DefaultDJ(Web):
 
     def __init__(self):
-        tier = "defaultdj"
+        tier = "defaultDJ"
         worker = "pju_worker"
         ami = "ami-1327167a"
         instance_type = "r3.xlarge"
