@@ -14,23 +14,28 @@ import logging
 
 
 class Scheduler(Tier):
-    tier = "scheduler"
-    ami_id = "ami-0598906c"
-    port = 9090
-    region = "us-east-1"
-    instance_type = "m3.medium"
-    run_list = '{"run_list":["recipe[webslave::deploy_scheduler]"],"qubole_tier":"scheduler"}'
-    modules = ["scheduler"]
 
-    def __init__(self, subparser):
-        super(Scheduler, self).__init__(subparser)
+    def __init__(self):
+        tier = "scheduler"
+        ami = "ami-0598906c"
+        region = "us-east-1"
+        instance_type = "m3.medium"
+        run_list = '{"run_list":["recipe[webslave::deploy_scheduler]"],"qubole_tier":"scheduler"}'
+        modules = ["scheduler"]
+        port = 9090
+        super(Scheduler, self).__init__(tier=tier, ami=ami, instance_type=instance_type,
+                                        region=region, run_list=run_list, modules=modules,
+                                        port=port)
+        self.is_autoscalable = False
 
+
+    def configure_parsers(self):
         # Create
         create = self.tier_parser.add_parser("create", help="Create Cron Tier")
         create.add_argument("-d", "--dry-run", help="Dry Run: Dont really create the tier",
                             default=False, dest="dry_run", action="store_true")
         create.add_argument("-a", "--ami-id", help="AMI ID to use for the CRON tier",
-                            default=self.ami_id, dest="ami_id")
+                            default=self.ami, dest="ami")
         create.add_argument("-r", "--region", help="Region where the tier will be located",
                             default=self.region, dest="region")
         create.add_argument("-i", "--instance-type", help="Instance Type of the machine",
@@ -97,7 +102,7 @@ class Scheduler(Tier):
             raise Exception("There is already a scheduler (%s, %s) in %s" % (instance.id, instance.state, self.tier))
 
         reservation = conn.run_instances(
-            args.ami_id,
+            args.ami,
             key_name=rows["value"],
             instance_type=args.instance_type,
             security_groups=["default"],
